# CMeel autoconf

[![PyPI version](https://badge.fury.io/py/cmeel-autoconf.svg)](https://pypi.org/project/cmeel-autoconf)
[![Release](https://github.com/cmake-wheel/cmeel-autoconf/actions/workflows/release.yml/badge.svg)](https://github.com/cmake-wheel/cmeel-autoconf/actions/workflows/release.yml)

[autoconf](https://www.gnu.org/software/autoconf/) distribution for cmeel packages.
